@@ -1133,10 +1133,18 @@ func (m *jsMinifier) minifyExpr(i js.IExpr, prec js.OpPrec) {
 		parentInFor := m.inFor
 		m.inFor = false
 		for _, item := range expr.List {
-			m.write(replaceEscapes(item.Value, '`', 1, 2))
+			if expr.Tag == nil {
+				m.write(replaceEscapes(item.Value, '`', 1, 2))
+			} else {
+				m.write(item.Value)
+			}
 			m.minifyExpr(item.Expr, js.OpExpr)
 		}
-		m.write(replaceEscapes(expr.Tail, '`', 1, 1))
+		if expr.Tag == nil {
+			m.write(replaceEscapes(expr.Tail, '`', 1, 1))
+		} else {
+			m.write(expr.Tail)
+		}
 		m.inFor = parentInFor
 	case *js.NewExpr:
 		if expr.Args == nil && js.OpLHS < prec && prec != js.OpNew {
