@@ -190,11 +190,15 @@ func optimizeStmtList(list []js.IStmt, blockType blockType) []js.IStmt {
 					j--
 				} else if forStmt, ok := list[i].(*js.ForStmt); ok {
 					// TODO: only merge lhs expression that don't have 'in' or 'of' keywords (slow to check?)
-					if varDecl, ok := forStmt.Init.(*js.VarDecl); ok {
-						if len(varDecl.List) == 0 || forStmt.Init == nil {
-							forStmt.Init = left.Value
-							j--
-						} else if mergeVarDeclExprStmt(varDecl, left, true) {
+					if forStmt.Init == nil {
+						forStmt.Init = left.Value
+						j--
+					} else if decl, ok := forStmt.Init.(*js.VarDecl); ok && len(decl.List) == 0 {
+						forStmt.Init = left.Value
+						j--
+					} else if ok && (decl.TokenType == js.VarToken || decl.TokenType == js.ErrorToken) {
+						// this is the second VarDecl, so we are hoisting var declarations, which means the forInit variables are already in 'left'
+						if merge := mergeVarDeclExprStmt(decl, left, true); merge {
 							j--
 						}
 					}
